@@ -37,7 +37,7 @@
 
 gr_fft_filter_fff_sptr gr_make_fft_filter_fff (int decimation, const std::vector<float> &taps)
 {
-  return gr_fft_filter_fff_sptr (new gr_fft_filter_fff (decimation, taps));
+  return gnuradio::get_initial_sptr(new gr_fft_filter_fff (decimation, taps));
 }
 
 
@@ -55,7 +55,7 @@ gr_fft_filter_fff::gr_fft_filter_fff (int decimation, const std::vector<float> &
 #else
     d_filter = new gri_fft_filter_fff_sse(decimation, taps);
 #endif
-
+  d_new_taps = taps;
   d_nsamples = d_filter->set_taps(taps);
   set_output_multiple(d_nsamples);
 }
@@ -72,6 +72,12 @@ gr_fft_filter_fff::set_taps (const std::vector<float> &taps)
   d_updated = true;
 }
 
+std::vector<float>
+gr_fft_filter_fff::taps () const
+{
+  return d_new_taps;
+}
+
 int
 gr_fft_filter_fff::work (int noutput_items,
 			 gr_vector_const_void_star &input_items,
