@@ -23,6 +23,7 @@
 #ifndef INCLUDED_GR_SINGLE_POLE_IIR_FILTER_FF_H
 #define	INCLUDED_GR_SINGLE_POLE_IIR_FILTER_FF_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
 #include <gr_single_pole_iir.h>
 #include <stdexcept>
@@ -30,7 +31,7 @@
 class gr_single_pole_iir_filter_ff;
 typedef boost::shared_ptr<gr_single_pole_iir_filter_ff> gr_single_pole_iir_filter_ff_sptr;
 
-gr_single_pole_iir_filter_ff_sptr 
+GR_CORE_API gr_single_pole_iir_filter_ff_sptr 
 gr_make_single_pole_iir_filter_ff (double alpha, unsigned int vlen=1);
 
 /*!
@@ -52,10 +53,10 @@ gr_make_single_pole_iir_filter_ff (double alpha, unsigned int vlen=1);
  * Note that some texts define the system function with a + in the denominator.
  * If you're using that convention, you'll need to negate the feedback tap.
  */
-class gr_single_pole_iir_filter_ff : public gr_sync_block
+class GR_CORE_API gr_single_pole_iir_filter_ff : public gr_sync_block
 {
  private:
-  friend gr_single_pole_iir_filter_ff_sptr 
+  friend GR_CORE_API gr_single_pole_iir_filter_ff_sptr 
   gr_make_single_pole_iir_filter_ff (double alpha, unsigned int vlen);
 
   unsigned int			        		d_vlen;
