@@ -23,6 +23,7 @@
 #ifndef INCLUDED_GR_COMPLEX_TO_XXX_H
 #define INCLUDED_GR_COMPLEX_TO_XXX_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
 #include <gr_complex.h>
 
@@ -40,21 +41,21 @@ typedef boost::shared_ptr<gr_complex_to_mag> gr_complex_to_mag_sptr;
 typedef boost::shared_ptr<gr_complex_to_mag_squared> gr_complex_to_mag_squared_sptr;
 typedef boost::shared_ptr<gr_complex_to_arg> gr_complex_to_arg_sptr;
 
-gr_complex_to_float_sptr gr_make_complex_to_float (unsigned int vlen=1);
-gr_complex_to_real_sptr gr_make_complex_to_real (unsigned int vlen=1);
-gr_complex_to_imag_sptr gr_make_complex_to_imag (unsigned int vlen=1);
-gr_complex_to_mag_sptr gr_make_complex_to_mag (unsigned int vlen=1);
-gr_complex_to_mag_squared_sptr gr_make_complex_to_mag_squared (unsigned int vlen=1);
-gr_complex_to_arg_sptr gr_make_complex_to_arg (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_float_sptr gr_make_complex_to_float (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_real_sptr gr_make_complex_to_real (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_imag_sptr gr_make_complex_to_imag (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_mag_sptr gr_make_complex_to_mag (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_mag_squared_sptr gr_make_complex_to_mag_squared (unsigned int vlen=1);
+GR_CORE_API gr_complex_to_arg_sptr gr_make_complex_to_arg (unsigned int vlen=1);
 
 /*!
  * \brief convert a stream of gr_complex to 1 or 2 streams of float
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_float : public gr_sync_block
+class GR_CORE_API gr_complex_to_float : public gr_sync_block
 {
-  friend gr_complex_to_float_sptr gr_make_complex_to_float (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_float_sptr gr_make_complex_to_float (unsigned int vlen);
   gr_complex_to_float (unsigned int vlen);
 
   unsigned int	d_vlen;
@@ -70,9 +71,9 @@ class gr_complex_to_float : public gr_sync_block
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_real : public gr_sync_block
+class GR_CORE_API gr_complex_to_real : public gr_sync_block
 {
-  friend gr_complex_to_real_sptr gr_make_complex_to_real (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_real_sptr gr_make_complex_to_real (unsigned int vlen);
   gr_complex_to_real (unsigned int vlen);
 
   unsigned int	d_vlen;
@@ -88,9 +89,9 @@ class gr_complex_to_real : public gr_sync_block
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_imag : public gr_sync_block
+class GR_CORE_API gr_complex_to_imag : public gr_sync_block
 {
-  friend gr_complex_to_imag_sptr gr_make_complex_to_imag (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_imag_sptr gr_make_complex_to_imag (unsigned int vlen);
   gr_complex_to_imag (unsigned int vlen);
 
   unsigned int	d_vlen;
@@ -106,9 +107,9 @@ class gr_complex_to_imag : public gr_sync_block
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_mag : public gr_sync_block
+class GR_CORE_API gr_complex_to_mag : public gr_sync_block
 {
-  friend gr_complex_to_mag_sptr gr_make_complex_to_mag (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_mag_sptr gr_make_complex_to_mag (unsigned int vlen);
   gr_complex_to_mag (unsigned int vlen);
 
   unsigned int	d_vlen;
@@ -124,9 +125,9 @@ class gr_complex_to_mag : public gr_sync_block
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_mag_squared : public gr_sync_block
+class GR_CORE_API gr_complex_to_mag_squared : public gr_sync_block
 {
-  friend gr_complex_to_mag_squared_sptr gr_make_complex_to_mag_squared (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_mag_squared_sptr gr_make_complex_to_mag_squared (unsigned int vlen);
   gr_complex_to_mag_squared (unsigned int vlen);
 
   unsigned int	d_vlen;
@@ -142,9 +143,9 @@ class gr_complex_to_mag_squared : public gr_sync_block
  * \ingroup converter_blk
  * \param vlen	vector len (default 1)
  */
-class gr_complex_to_arg : public gr_sync_block
+class GR_CORE_API gr_complex_to_arg : public gr_sync_block
 {
-  friend gr_complex_to_arg_sptr gr_make_complex_to_arg (unsigned int vlen);
+  friend GR_CORE_API gr_complex_to_arg_sptr gr_make_complex_to_arg (unsigned int vlen);
   gr_complex_to_arg (unsigned int vlen);
 
   unsigned int	d_vlen;
