@@ -23,12 +23,13 @@
 #ifndef INCLUDED_GR_FREQUENCY_MODULATOR_FC_H
 #define INCLUDED_GR_FREQUENCY_MODULATOR_FC_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
 
 class gr_frequency_modulator_fc;
 typedef boost::shared_ptr<gr_frequency_modulator_fc> gr_frequency_modulator_fc_sptr;
 
-gr_frequency_modulator_fc_sptr gr_make_frequency_modulator_fc (double sensitivity);
+GR_CORE_API gr_frequency_modulator_fc_sptr gr_make_frequency_modulator_fc (double sensitivity);
 
 /*!
  * \brief Frequency modulator block
@@ -36,18 +37,20 @@ gr_frequency_modulator_fc_sptr gr_make_frequency_modulator_fc (double sensitivit
  *
  * float input; complex baseband output
  */
-class gr_frequency_modulator_fc : public gr_sync_block
+class GR_CORE_API gr_frequency_modulator_fc : public gr_sync_block
 {
   double	d_sensitivity;
   double	d_phase;
 
-  friend gr_frequency_modulator_fc_sptr
+  friend GR_CORE_API gr_frequency_modulator_fc_sptr
   gr_make_frequency_modulator_fc (double sensitivity);
 
   gr_frequency_modulator_fc (double sensitivity);
 
  public:
-
+  void set_sensitivity(float sens) { d_sensitivity = sens; }
+  float sensitivity() const { return d_sensitivity; }
+  
   int work (int noutput_items,
 	    gr_vector_const_void_star &input_items,
 	    gr_vector_void_star &output_items);
