@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2011 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -23,13 +23,16 @@
 #ifndef INCLUDED_GR_PLL_FREQDET_CF_H
 #define INCLUDED_GR_PLL_FREQDET_CF_H
 
+#include <gr_core_api.h>
 #include <gr_sync_block.h>
+#include <gri_control_loop.h>
 
 class gr_pll_freqdet_cf;
 typedef boost::shared_ptr<gr_pll_freqdet_cf> gr_pll_freqdet_cf_sptr;
 
-gr_pll_freqdet_cf_sptr gr_make_pll_freqdet_cf (float alpha, float beta,
-					       float max_freq, float min_freq);
+GR_CORE_API gr_pll_freqdet_cf_sptr gr_make_pll_freqdet_cf (float loop_bw,
+					       float max_freq,
+					       float min_freq);
 /*!
  * \brief Implements a PLL which locks to the input frequency and outputs 
  * an estimate of that frequency.  Useful for FM Demod.
@@ -40,24 +43,24 @@ gr_pll_freqdet_cf_sptr gr_make_pll_freqdet_cf (float alpha, float beta,
  * This PLL locks onto a [possibly noisy] reference carrier on
  * the input and outputs an estimate of that frequency in radians per sample.
  * All settings max_freq and min_freq are in terms of radians per sample, 
- * NOT HERTZ.  Alpha is the phase gain (first order, units of radians per radian) 
- * and beta is the frequency gain (second order, units of radians per sample per radian)
+ * NOT HERTZ.  The loop bandwidth determins the lock range and should be set
+ * around pi/200 -- 2pi/100.
  * \sa gr_pll_refout_cc, gr_pll_carriertracking_cc
  */
 
-class gr_pll_freqdet_cf : public gr_sync_block
+class GR_CORE_API gr_pll_freqdet_cf : public gr_sync_block, public gri_control_loop
 {
-  friend gr_pll_freqdet_cf_sptr gr_make_pll_freqdet_cf (float alpha, float beta,
-							float max_freq, float min_freq);
+  friend GR_CORE_API gr_pll_freqdet_cf_sptr gr_make_pll_freqdet_cf (float loop_bw,
+							float max_freq,
+							float min_freq);
 
-  float d_alpha,d_beta,d_max_freq,d_min_freq,d_phase,d_freq;
-  gr_pll_freqdet_cf (float alpha, float beta, float max_freq, float min_freq);
+  float mod_2pi (float in);
+  gr_pll_freqdet_cf (float loop_bw, float max_freq, float min_freq);
 
   int work (int noutput_items,
 	    gr_vector_const_void_star &input_items,
 	    gr_vector_void_star &output_items);
 private:
-  float mod_2pi (float in);
   float phase_detector(gr_complex sample,float ref_phase);
 };
 
