@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2003,2008 Free Software Foundation, Inc.
+ * Copyright 2003,2008,2011 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -21,7 +21,21 @@
  */
 
 #include <gri_fft.h>
+#include <gr_sys_paths.h>
 #include <fftw3.h>
+
+#ifdef _MSC_VER //http://www.fftw.org/install/windows.html#DLLwisdom
+static void my_fftw_write_char(char c, void *f) { fputc(c, (FILE *) f); }
+#define fftw_export_wisdom_to_file(f) fftw_export_wisdom(my_fftw_write_char, (void*) (f))
+#define fftwf_export_wisdom_to_file(f) fftwf_export_wisdom(my_fftw_write_char, (void*) (f))
+#define fftwl_export_wisdom_to_file(f) fftwl_export_wisdom(my_fftw_write_char, (void*) (f))
+
+static int my_fftw_read_char(void *f) { return fgetc((FILE *) f); }
+#define fftw_import_wisdom_from_file(f) fftw_import_wisdom(my_fftw_read_char, (void*) (f))
+#define fftwf_import_wisdom_from_file(f) fftwf_import_wisdom(my_fftw_read_char, (void*) (f))
+#define fftwl_import_wisdom_from_file(f) fftwl_import_wisdom(my_fftw_read_char, (void*) (f))
+#endif //_MSC_VER
+
 #include <gr_complex.h>
 #include <stdlib.h>
 #include <string.h>
@@ -29,6 +43,9 @@
 #include <cassert>
 #include <stdexcept>
 
+#include <boost/filesystem/operations.hpp>
+#include <boost/filesystem/path.hpp>
+namespace fs = boost::filesystem;
 
 boost::mutex &
 gri_fft_planner::mutex()
@@ -38,26 +55,18 @@ gri_fft_planner::mutex()
   return s_planning_mutex;
 }
 
-static char *
+static const char *
 wisdom_filename ()
 {
-  static const char *filename = ".gr_fftw_wisdom";
-
-  char	*home = getenv ("HOME");
-  if (home){
-    char *p = new char[strlen (home) + strlen (filename) + 2];
-    strcpy (p, home);
-    strcat (p, "/");
-    strcat (p, filename);
-    return p;
-  }
-  return 0;
+  static fs::path path;
+  path = fs::path(gr_appdata_path()) / ".gr_fftw_wisdom";
+  return path.string().c_str();
 }
 
 static void 
 gri_fftw_import_wisdom ()
 {
-  char *filename = wisdom_filename ();
+  const char *filename = wisdom_filename ();
   FILE *fp = fopen (filename, "r");
   if (fp != 0){
     int r = fftwf_import_wisdom_from_file (fp);
@@ -66,13 +75,12 @@ gri_fftw_import_wisdom ()
       fprintf (stderr, "gri_fftw: can't import wisdom from %s\n", filename);
     }
   }
-  delete [] filename;
 }
 
 static void
 gri_fftw_export_wisdom ()
 {
-  char *filename = wisdom_filename ();
+  const char *filename = wisdom_filename ();
   FILE *fp = fopen (filename, "w");
   if (fp != 0){
     fftwf_export_wisdom_to_file (fp);
@@ -82,7 +90,6 @@ gri_fftw_export_wisdom ()
     fprintf (stderr, "gri_fftw: ");
     perror (filename);
   }
-  delete [] filename;
 }
 
 // ----------------------------------------------------------------
