@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004,2008,2009 Free Software Foundation, Inc.
+ * Copyright 2004,2008,2009,2010 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -29,6 +29,7 @@
 #include <gr_block_detail.h>
 #include <gr_buffer.h>
 #include <boost/thread.hpp>
+#include <boost/format.hpp>
 #include <iostream>
 #include <limits>
 #include <assert.h>
@@ -87,15 +88,79 @@ min_available_space (gr_block_detail *d, int output_multiple)
   return min_space;
 }
 
+static bool
+propagate_tags(gr_block::tag_propagation_policy_t policy, gr_block_detail *d,
+	       const std::vector<uint64_t> &start_nitems_read, double rrate,
+	       std::vector<gr_tag_t> &rtags)
+{
+  // Move tags downstream
+  // if a sink, we don't need to move downstream
+  if(d->sink_p()) {
+    return true;
+  }
 
+  switch(policy) {
+  case gr_block::TPP_DONT:
+    return true;
+    break;
+  case gr_block::TPP_ALL_TO_ALL:
+    // every tag on every input propogates to everyone downstream
+    for(int i = 0; i < d->ninputs(); i++) {
+      d->get_tags_in_range(rtags, i, start_nitems_read[i],
+			   d->nitems_read(i));
 
-gr_block_executor::gr_block_executor (gr_block_sptr block)
-  : d_block(block), d_log(0)
+      std::vector<gr_tag_t>::iterator t;
+      if(rrate == 1.0) {
+	for(t = rtags.begin(); t != rtags.end(); t++) {
+	  for(int o = 0; o < d->noutputs(); o++)
+	    d->output(o)->add_item_tag(*t);
+	}
+      }
+      else {
+	for(t = rtags.begin(); t != rtags.end(); t++) {
+	  gr_tag_t new_tag = *t;
+	  new_tag.offset *= rrate;
+	  for(int o = 0; o < d->noutputs(); o++)
+	    d->output(o)->add_item_tag(new_tag);
+	}
+      }
+    }
+    break;
+  case gr_block::TPP_ONE_TO_ONE:
+    // tags from input i only go to output i
+    // this requires d->ninputs() == d->noutputs; this is checked when this
+    // type of tag-propagation system is selected in gr_block_detail
+    if(d->ninputs() == d->noutputs()) {
+      for(int i = 0; i < d->ninputs(); i++) {
+	d->get_tags_in_range(rtags, i, start_nitems_read[i],
+			     d->nitems_read(i));
+
+	std::vector<gr_tag_t>::iterator t;
+	for(t = rtags.begin(); t != rtags.end(); t++) {
+	  gr_tag_t new_tag = *t;
+	  new_tag.offset *= rrate;
+	  d->output(i)->add_item_tag(new_tag);
+	}
+      }
+    }
+    else  {
+      std::cerr << "Error: gr_block_executor: propagation_policy 'ONE-TO-ONE' requires ninputs == noutputs" << std::endl;
+      return false;
+    }
+    
+    break;
+  default:
+    return true;
+  }
+  return true;
+}
+
+gr_block_executor::gr_block_executor (gr_block_sptr block, int max_noutput_items)
+  : d_block(block), d_log(0), d_max_noutput_items(max_noutput_items)
 {
   if (ENABLE_LOGGING){
-    char name[100];
-    snprintf(name, sizeof(name), "sst-%03d.log", which_scheduler++);
-    d_log = new std::ofstream(name);
+    std::string name = str(boost::format("sst-%03d.log") % which_scheduler++);
+    d_log = new std::ofstream(name.c_str());
     std::unitbuf(*d_log);		// make it unbuffered...
     *d_log << "gr_block_executor: "
 	   << d_block << std::endl;
@@ -117,6 +182,7 @@ gr_block_executor::run_one_iteration()
 {
   int			noutput_items;
   int			max_items_avail;
+  int                   max_noutput_items = d_max_noutput_items;
 
   gr_block		*m = d_block.get();
   gr_block_detail	*d = m->detail().get();
@@ -134,9 +200,11 @@ gr_block_executor::run_one_iteration()
     d_input_items.resize (0);
     d_input_done.resize(0);
     d_output_items.resize (d->noutputs ());
+    d_start_nitems_read.resize(0);
 
     // determine the minimum available output space
     noutput_items = min_available_space (d, m->output_multiple ());
+    noutput_items = std::min(noutput_items, d_max_noutput_items);
     LOG(*d_log << " source\n  noutput_items = " << noutput_items << std::endl);
     if (noutput_items == -1)		// we're done
       goto were_done;
@@ -155,6 +223,7 @@ gr_block_executor::run_one_iteration()
     d_input_items.resize (d->ninputs ());
     d_input_done.resize(d->ninputs());
     d_output_items.resize (0);
+    d_start_nitems_read.resize(d->ninputs());
     LOG(*d_log << " sink\n");
 
     max_items_avail = 0;
@@ -180,6 +249,7 @@ gr_block_executor::run_one_iteration()
     // take a swag at how much output we can sink
     noutput_items = (int) (max_items_avail * m->relative_rate ());
     noutput_items = round_down (noutput_items, m->output_multiple ());
+    noutput_items = std::min(noutput_items, d_max_noutput_items);
     LOG(*d_log << "  max_items_avail = " << max_items_avail << std::endl);
     LOG(*d_log << "  noutput_items = " << noutput_items << std::endl);
 
@@ -198,6 +268,7 @@ gr_block_executor::run_one_iteration()
     d_input_items.resize (d->ninputs ());
     d_input_done.resize(d->ninputs());
     d_output_items.resize (d->noutputs ());
+    d_start_nitems_read.resize(d->ninputs());
 
     max_items_avail = 0;
     for (int i = 0; i < d->ninputs (); i++){
@@ -239,7 +310,11 @@ gr_block_executor::run_one_iteration()
       reqd_noutput_items = round_up(reqd_noutput_items, m->output_multiple());
       if (reqd_noutput_items > 0 && reqd_noutput_items <= noutput_items)
 	noutput_items = reqd_noutput_items;
+
+      // if we need this many outputs, overrule the max_noutput_items setting
+      max_noutput_items = std::max(m->output_multiple(), max_noutput_items);
     }
+    noutput_items = std::min(noutput_items, max_noutput_items);
 
     // ask the block how much input they need to produce noutput_items
     m->forecast (noutput_items, d_ninput_items_required);
@@ -294,12 +369,21 @@ gr_block_executor::run_one_iteration()
     for (int i = 0; i < d->noutputs (); i++)
       d_output_items[i] = d->output(i)->write_pointer();
 
+    // determine where to start looking for new tags
+    for (int i = 0; i < d->ninputs(); i++)
+      d_start_nitems_read[i] = d->nitems_read(i);
+
     // Do the actual work of the block
     int n = m->general_work (noutput_items, d_ninput_items,
 			     d_input_items, d_output_items);
     LOG(*d_log << "  general_work: noutput_items = " << noutput_items
 	<< " result = " << n << std::endl);
 
+    if(!propagate_tags(m->tag_propagation_policy(), d,
+		       d_start_nitems_read, m->relative_rate(),
+		       d_returned_tags))
+      goto were_done;
+
     if (n == gr_block::WORK_DONE)
       goto were_done;
 
