@@ -23,12 +23,13 @@
 #ifndef INCLUDED_TRELLIS_INTERLEAVER_H
 #define INCLUDED_TRELLIS_INTERLEAVER_H
 
+#include <trellis_api.h>
 #include <vector>
 
 /*!
  * \brief  INTERLEAVER class
  */
-class interleaver {
+class TRELLIS_API interleaver {
 private:
   int d_K;
   std::vector<int> d_INTER;
